# Machine Heads External Nodes

## Getting Started

**Machine Heads External Nodes** is a python module for creating your own nodes for use on [Machine Heads](https://mheads.net).
Using *External Nodes* you will be able to:
* Create your own nodes
* Receive data (including images) from *Machine Heads* nodes
* Send data (including images) to *Machine Heads* nodes
* Run any python code on *Machine Heads* test sequence

## Installation

Use the following command to install *Machine Heads External Nodes*:

```
pip install mh_en_exec
```

*Machine Heads External Nodes* is now installed. Check out the [quickstart](https://mheads.net/external_nodes/en/quickstart.html) to learn how to create a node and start the *External Nodes* server.

## Examples

There is also a sample code in the "examples" folder.
To execute sample code, just install "mh_en_exec" and call the following command:

```
python run.py
```
